pub enum MarkdownNode {
Heading {
level: HeadingLevel,
text: Text,
},
Paragraph {
text: Text,
},
BlockQuote {
kind: Option<BlockQuoteKind>,
nodes: Vec<Node>,
},
CodeBlock {
lang: Option<String>,
text: Text,
},
List {
kind: ListKind,
nodes: Vec<Node>,
},
Item {
text: Text,
},
TaskListItem {
kind: TaskListItemKind,
text: Text,
},
}Expand description
The Markdown AST node enumeration.
Variants
Heading
A heading node that represents different heading levels.
The level is controlled with the HeadingLevel definition.
Paragraph
A paragraph
BlockQuote
A block quote node that represents different quote block variants including callout blocks.
The variant is controlled with the BlockQuoteKind definition. When BlockQuoteKind
is None the block quote should be interpreted as a regular block quote:
"> Block quote".
CodeBlock
A fenced code block, optionally with a language identifier.
List
A block for list items.
The list variant is controlled with the ListKind definition.
Item
A list item node that represents different list item variants including task items.
The variant is controlled with the ItemKind definition. When ItemKind is None
the item should be interpreted as unordered list item: "- Item".
TaskListItem