pub enum TaskListItemKind {
Checked,
Unchecked,
LooselyChecked,
}Expand description
Represents the variant of a list or task item (checked, unchecked, etc.).
Variants
Checked
A checkbox item that is marked as done using - [x].
Unchecked
A checkbox item that is unchecked using - [ ].
LooselyChecked
A checkbox item that is checked, but not explicitly recognized as
Checked (e.g., - [?]).