pub struct CharCount(/* private fields */);Expand description
A wrapper type representing the number of characters in a string. All characters are counted for.
Character count can be created from an usize directly or computed from a &str.