pub struct WordCount(/* private fields */);Expand description
A wrapper type representing the number of words in a string.
Can be created from a usize directly or computed from a &str by counting the number of
whitespace-separated words, after removing special markdown characters.
markdown characters: * _ ` < > ? ! [ ] ( ) = ~ # +